#!/usr/bin/env python

import os
import subprocess
import time

try:
    import RPi.GPIO as GPIO
except ImportError:
    from dummy import GPIO


class DeviceController(object):

    def __init__(self, pin, actions):
        self.pin = pin
        self.actions = sorted([(t, a) for t, a in actions.items()], reverse=True)
        GPIO.setmode(GPIO.BCM)  # set up BCM GPIO numbering
        GPIO.setup(self.pin, GPIO.IN, pull_up_down=GPIO.PUD_UP)

    def run(self):
        while True:
            t0 = time.time()
            while not GPIO.input(self.pin):
                time.sleep(0.2)
            delta_t = time.time() - t0
            self.execute_script(delta_t)
            time.sleep(0.2)

    def execute_script(self, hold_time):
        for t, a in self.actions:
            if hold_time > t:
                print(f'Executing action {a}...')
                subprocess.call(['bash', os.path.join(os.path.split(__file__)[0], 'scripts', a)])
                return


if __name__ == '__main__':
    print('Starting Device Controller')
    device_controller = DeviceController(
        pin=10,
        actions={
            1: 'hotspot.sh',
            5: 'shutdown.sh'
        }
    )
    device_controller.run()
