
var SVG = {
    line: function(svg, x1, y1, x2, y2, scale, stroke_style, stroke_dasharray, onclick) {
        if (!scale) scale = 1.0;
        var line = document.createElementNS('http://www.w3.org/2000/svg', 'line');
        line.setAttribute('x1', x1 * scale);
        line.setAttribute('y1', y1 * scale);
        line.setAttribute('x2', x2 * scale);
        line.setAttribute('y2', y2 * scale);
        if (stroke_style) line.setAttribute('style', stroke_style);
        if (stroke_dasharray) line.setAttribute('stroke-dasharray', stroke_dasharray);
        if (onclick) line.setAttribute('onclick', onclick);
        svg.appendChild(line);
        return line;
    },

    circle: function(svg, cx, cy, r, scale, style, onclick) {
        if (!scale) scale = 1.0;
        var circle = document.createElementNS('http://www.w3.org/2000/svg', 'circle');
        circle.setAttribute('cx', cx * scale);
        circle.setAttribute('cy', cy * scale);
        circle.setAttribute('r', r * scale);
        if (style) circle.setAttribute('style', style);
        if (onclick) circle.setAttribute('onclick', onclick);
        svg.appendChild(circle);
        return circle;
    },

    polyline: function(svg, points, scale, style, onclick) {
        if (!scale) scale = 1.0;
        var poly = document.createElementNS('http://www.w3.org/2000/svg', 'polyline');
        if (!scale) scale = 1.0;
        p = ''
        for (var i=0; i<points.length; i++) {
            p += ' ' + points[i].x * scale + ',' + points[i].y * scale;
        }
        poly.setAttribute('points', p);
        if (style) poly.setAttribute('style', style);
        if (onclick) poly.setAttribute('onclick', onclick);
        svg.appendChild(poly);
        return poly;
    },

    polygon: function(svg, points, scale, style, onclick) {
        if (!scale) scale = 1.0;
        var poly = document.createElementNS('http://www.w3.org/2000/svg', 'polygon');
        p = ''
        for (var i=0; i<points.length; i++) {
            p += ' ' + points[i].x * scale + ',' + points[i].y * scale;
        }
        poly.setAttribute('points', p);
        if (style) poly.setAttribute('style', style);
        if (onclick) poly.setAttribute('onclick', onclick);
        svg.appendChild(poly);
        return poly;
    },

    rect: function(svg, x, y, width, height, scale, label, rectangle_style, label_style, corner_radius, onclick) {
        if (!scale) scale = 1.0;
        var rect = document.createElementNS('http://www.w3.org/2000/svg', 'rect');
        rect.setAttribute('x', x * scale);
        rect.setAttribute('y', y * scale);
        rect.setAttribute('width', width * scale);
        rect.setAttribute('height', height * scale);
        if (corner_radius) {
            rect.setAttribute('rx', corner_radius * scale);
            rect.setAttribute('ry', corner_radius * scale);
        };
        if (rectangle_style) rect.setAttribute('style', rectangle_style);
        if (onclick) rect.setAttribute('onclick', onclick);
        svg.appendChild(rect);
        if (label) SVG.label(svg, label, x + width / 2, y + height / 2, scale, 90, label_style);
        return rect;
    },

    label: function(svg, label_text, x, y, scale, rotation, label_style, text_anchor, onclick) {
        if (!scale) scale = 1.0;
        var text = document.createElementNS('http://www.w3.org/2000/svg', 'text');
        text.setAttribute('text-anchor', text_anchor ? text_anchor : 'middle');
        text.setAttribute('alignment-baseline', 'central');
        text.setAttribute('x', x * scale);
        text.setAttribute('y', y * scale);
        text.textContent = label_text;
        if (label_style) text.setAttribute('style', label_style);
        if (rotation != 0) text.setAttribute('transform', 'rotate(' + rotation + ' ' + x + ',' + y +')');
        if (onclick) rect.setAttribute('onclick', onclick);
        svg.appendChild(text);
        return text;
    },

    clear: function(svg) {
        while (svg && svg.firstChild) {
            svg.removeChild(svg.firstChild);
        }
    }
}
