#!/usr/bin/env python
"""
Web Controller
"""

import argparse
import subprocess

from flask import Flask, render_template, make_response
from flask_socketio import SocketIO
from rc_thing.controller import Controller

app = Flask(__name__, static_url_path='/static', static_folder='static')
app.config['SECRET_KEY'] = 'secret!'
socketio = SocketIO(app)
controller = Controller()


@app.route('/')
def index():
    return render_template('index.html')

@app.route('/dlpic')
def dlpic():
    data = subprocess.check_output(['raspistill', '-t', '500', '-n', '-o', '-'])
    response = make_response(data)
    response.headers.set('Content-Type', 'image/jpeg')
    response.headers.set('Content-Disposition', 'attachment', filename='pic.jpg')
    return response

@app.route('/pic')
def pic():
    data = subprocess.check_output(['raspistill', '-t', '500', '-n', '-o', '-'])
    response = make_response(data)
    response.headers.set('Content-Type', 'image/jpeg')
    return response

@socketio.on('control')
def handle_json(json):
    controller.accept_command(json['L'], json['R'])


@socketio.on('messages')
def handle_my_custom_event(text):
    print('>', text['data'])


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('--port', type=int, default=5000, help='webserver port')
    args = parser.parse_args()
    socketio.run(app, host='0.0.0.0', port=args.port, debug=False)
